@@ -1,6 +1,7 @@
 import argparse
 import time
 import requests
+import sys
 from bs4 import BeautifulSoup
 
 
@@ -9,7 +10,7 @@ Cambridge is a terminal version of Cambridge Dictionary. Its dictionary data com
 
 Parsing takes less than 0.4 seconds.
 Most of the time is spent on fetching webpage.
-Total time is between 1 to 5 seconds depending on network performance.
+Total time is mostly between 0.5 to 3 seconds, occasionally 5 secs at most depending on network performance.
 """
 
 DICT_BASE_URL = "https://dictionary.cambridge.org/dictionary/english/"
@@ -34,14 +35,24 @@ def fetch(url, session):
         "User-Agent": "Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/29.0.1547.62 Safari/537.36"
     }
     session.headers.update(headers)
-    try:
-        r = session.get(url)
-    except requests.exceptions.ConnectTimeout:
-        logger.error("Timeout fetching %s", url)
-    except Exception as e:
-        logger.error("Error fetching %s", url, exec_info=e)
-    else:
-        return r
+    attempt = 0
+    while True:
+        if attempt == 3:
+            logger.info("Maximum amount of url fetch retries reached")
+            sys.exit(0)
+        try:
+            r = session.get(url)
+            attempt += 1
+        except requests.exceptions.ConnectTimeout:
+            logger.error("Timed out during fetching %s. Retrying...", url)
+            time.sleep(0.1)
+        except requests.exceptions.ConnectionError:
+            logger.error("%s terminated connection. Retrying...", url)
+            time.sleep(0.1)
+        except Exception:
+            logger.exception("Error occured during fetching %s", url)
+        else:
+            return r
 
 
 def parse_spellcheck(args, session):
@@ -65,8 +76,19 @@ def parse_spellcheck(args, session):
 
 def parse_first_dict(response):
     soup = BeautifulSoup(response.text, "lxml")
-    first_dict = soup.find("div", "pr dictionary")
-    return first_dict
+
+    attempt = 0
+    while True:
+        if attempt == 3:
+            logger.info("Something went wrong with beautifulsoup. Please try later")
+            sys.exit(0)
+        first_dict = soup.find("div", "pr dictionary")
+        attempt += 1
+        if not first_dict:
+            logger.error("Beautifulsoup found None after response for the word has been successfully fetched. Retrying...")
+            time.sleep(0.1)
+        else:
+            return first_dict
 
 
 def parse_dict_blocks(response):
@@ -101,9 +123,11 @@ def parse_head_type(head):
             ).text
         )
         w_type = replace_all(w_type).upper()
-    if head.find("div", "posgram dpos-g hdib lmr-5"):
+    elif head.find("div", "posgram dpos-g hdib lmr-5"):
         posgram = head.find("div", "posgram dpos-g hdib lmr-5")
         w_type = replace_all(posgram.text).upper()
+    else:
+        w_type = None
     return w_type
 
 
@@ -146,7 +170,7 @@ def parse_head_var(head):
         w_var = replace_all(head.find("span", "var dvar").text)
         console.print("[bold]" + w_var, end="  ")
     if head.find_next_sibling("span", "var dvar"):
-        w_vjjjjar = replace_all(head.find_next_sibling("span", "var dvar").text)
+        w_var = replace_all(head.find_next_sibling("span", "var dvar").text)
         console.print("[bold]" + w_var, end="  ")
 
 
@@ -218,7 +242,6 @@ def parse_def_info(def_block):
         if "phrase-body" in def_block.parent.attrs["class"]:
             print("  " + "\033[1m" + def_info + " " + "\033[0m", end="")
         else:
-            # print("\033[1m" + def_info + " " + "\033[0m", end="")
             print(def_info + " ", end="")
 
 
@@ -228,10 +251,10 @@ def parse_meaning(def_block):
         usage_b = meaning_b.find("span", "lab dlab")
         usage = replace_all(usage_b.text)
         meaning_words = replace_all(meaning_b.text).split(usage)[-1]
-        console.print(usage + "[#F5A962]" + meaning_words)
+        print(usage + "\033[33m" + meaning_words + "\033[0m")
     else:
         meaning_words = replace_all(meaning_b.text)
-        console.print("[#F5A962]" + meaning_words)
+        print("\033[33m" + meaning_words + "\033[0m")
 
 
 def parse_pmeaning(def_block):
@@ -240,10 +263,10 @@ def parse_pmeaning(def_block):
         usage_b = meaning_b.find("span", "lab dlab")
         usage = replace_all(usage_b.text)
         meaning_words = replace_all(meaning_b.text).split(usage)[-1]
-        console.print(usage + "[#F5A962]" + meaning_words)
+        print("  " + usage + "\033[33m" + meaning_words + "\033[0m")
     else:
         meaning_words = replace_all(meaning_b.text)
-        console.print("[#F5A962]" + meaning_words)
+        print("  " + "\033[33m" + meaning_words + "\033[0m")
 
 
 def parse_example(def_block):
